@@ -8,11 +8,11 @@ URL::Normalize - Normalize/optimize URLs.
 
 =head1 VERSION
 
-Version 0.06
+Version 0.07
 
 =cut
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 use URI qw();
 use URI::QueryParam qw();
@@ -481,8 +481,7 @@ sub remove_empty_query {
 
 =head2 remove_fragment()
 
-Removes fragments from the URL. This is dangerous, as lot of AJAX-ified
-applications uses this part.
+Removes fragments from the URL.
 
 Example:
 
@@ -563,6 +562,17 @@ sub do_all {
     return 1;
 }
 
+=head1 PERFORMANCE
+
+There's probably possible to improve the performance of this module
+considerably, but as premature optimization is evil, I'll wait until the
+functionality and API is stable.
+
+On my MacBook Pro (2.66GHz i7, 8GB RAM) I'm able to run the do_all() method on
+more than 1,100 URLs per second. That should be enough for everyone. :)
+
+=cut
+
 =head1 SEE ALSO
 
 =over 4
